/*
 * ================  AccordionLayout config  =======================
 */

    MasksDataStore = new Ext.data.Store({
	id: 'MasksDataStore',
	proxy: new Ext.data.HttpProxy({
	    url: serverPhpUrl + '&target=getListOfVGroups',
	    method: 'POST'
	}),
	baseParams:{task: "LISTING"}, // this parameter is passed for any HTTP request
	reader: new Ext.data.JsonReader({
	    root: 'results',
	    totalProperty: 'total',
	    id: 'id'
	},[
	    {name: 'VGroupID', type: 'string', mapping: 'VGroupID'},
	    {name: 'VGroupName', type: 'string', mapping: 'VGroupName'},
	    {name: 'NumberOfElements', type: 'string', mapping: 'NumberOfElements'},
	    {name: 'NumberOfGroups', type: 'string', mapping: 'NumberOfGroups'},
	    {name: 'DateOfCreation', type: 'string', mapping: 'BirthDate'},
	]),
	sortInfo:{field: 'VGroupID', direction: "ASC"}
    });

    MasksColumnModel = new Ext.grid.ColumnModel(
	[{
	    header: 'Virtual Group ID',
	    readOnly: true,
	    dataIndex: 'VGroupID',
	    width: 200,
	    hidden: false
	},{
	    header: 'Virtual Group Name',
	    readOnly: true,
	    dataIndex: 'VGroupName',
	    width: 200,
	    hidden: false
	},{
	    header: 'Number Of Elements',
	    readOnly: true,
	    dataIndex: 'NumberOfElements',
	    width: 120,
	    hidden: false
	},{
	    header: 'Number Of Groups',
	    readOnly: true,
	    dataIndex: 'NumberOfGroups',
	    width: 120,
	    hidden: false
	},{
	    header: 'Date Of Creation',
	    readOnly: true,
	    dataIndex: 'DateOfCreation',
	    width: 110,
	    hidden: false
	}]
    );

    VGroupListingEditorGrid = new Ext.grid.EditorGridPanel({
	id: 'VGroupListingEditorGrid',
	width: 800,
	hegiht: 600,
	store: MasksDataStore,
	cm: MasksColumnModel,
	enableColLock:false,
	clicksToEdit:1,
	selModel: new Ext.grid.RowSelectionModel({singleSelect:false}),
	tbar: [
	{
		text: 'Delete selection',
		tooltip: 'bla bla bla',
		iconCls:'remove',
		handler: function(){
		    selectedNodes = VGroupListingEditorGrid.selModel.getSelections();
		    jsonOfIDs = {
			vGroupId: []
		    }
		    for(i=0; i<selectedNodes.length; i++){
			jsonOfIDs.vGroupId[i] = selectedNodes[i].get("VGroupID");
		    }
		    encodedjsonOfIDs = Ext.util.JSON.encode(jsonOfIDs);
		    Ext.Ajax.request({
			url : serverPhpUrl + '&target=removeMasks',
			params : {
			    "maskElementsJson": encodedjsonOfIDs
			},
			method: 'POST',
			timeout: 60000,
			success: function ( result, request ) {
			    jsonAckObj = Ext.util.JSON.decode(result.responseText);
			    MasksDataStore.load();
			    Ext.MessageBox.alert('Success', result.responseText);
			},
			failure: function ( result, request) {
			    Ext.MessageBox.alert('Failed', result.responseText);
			}
		    });
		}
	},{
	    text: 'Refresh',
	    iconCls: 'reload',
	    handler: function(){
		MasksDataStore.reload();
	    }
	},{
	    text: 'Edit',
	    handler: function(){
		selectedNodes = VGroupListingEditorGrid.selModel.getSelections();
		if(selectedNodes.length > 1){
		    Ext.MessageBox.alert('Failed', 'You can edit only one mask.');
		    return;
		}else{
		    selectedNode = selectedNodes[0].get("VGroupID");
		}
		Ext.Ajax.request({
		    url : serverPhpUrl + '&target=getVGroupInfo',
		    params : {
			"VGroupIdForEdit": selectedNode
		    },
		    method: 'POST',
		    timeout: 60000,
		    success: function ( result, request ) {
			jsonAckObj = Ext.util.JSON.decode(result.responseText);
			loadVGroupForEdit(jsonAckObj);
		    },
		    failure: function ( result, request) {
			Ext.MessageBox.alert('Failed', result.responseText);
		    }
		});

		Ext.getCmp('content-panel').layout.setActiveItem('createNewVGroup-panel');
		Ext.getCmp('navigation-tree-panel').selectPath('/navigationMenu/vGroupOperations/createNewVGroup');
	    }
	}
    ]
    });
    MasksDataStore.load();

    var manageVGroupsPanel = {
	id:'manageVGroups-panel',
	width: 600,
	height: 600,
	items: [
	    VGroupListingEditorGrid
	]
    };
